@@ -7,6 +7,10 @@
 
 #include "common/MemoryBuffer.hpp"
 
+namespace ancient::internal
+{
+
+
 class DMSDecompressor : public Decompressor
 {
 public:
@@ -24,7 +28,7 @@ public:
 	virtual void decompressImpl(Buffer &rawData,bool verify) override final;
 
 	static bool detectHeader(uint32_t hdr) noexcept;
-	static std::unique_ptr<Decompressor> create(const Buffer &packedData,bool exactSizeKnown,bool verify);
+	static std::shared_ptr<Decompressor> create(const Buffer &packedData,bool exactSizeKnown,bool verify);
 
 private:
 	void decompressImpl(Buffer &rawData,bool verify,uint32_t &restartPosition);
@@ -45,8 +49,8 @@ private:
 	uint32_t	_minTrack;
 	bool		_isHD;
 	bool		_isObsfuscated;
-
-	static Decompressor::Registry<DMSDecompressor> _registration;
 };
 
+}
+
 #endif
