@@ -3,7 +3,10 @@
 #ifndef LH1DECOMPRESSOR_HPP
 #define LH1DECOMPRESSOR_HPP
 
-#include "../Decompressor.hpp"
+#include "Decompressor.hpp"
+
+namespace ancient::internal
+{
 
 class LH1Decompressor : public Decompressor
 {
@@ -22,4 +25,6 @@ private:
 	const Buffer	&_packedData;
 };
 
+}
+
 #endif
