@@ -5,10 +5,13 @@
 
 #include "XPKDecompressor.hpp"
 
+namespace ancient::internal
+{
+
 class MASHDecompressor : public XPKDecompressor
 {
 public:
-	MASHDecompressor(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::unique_ptr<XPKDecompressor::State> &state,bool verify);
+	MASHDecompressor(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::shared_ptr<XPKDecompressor::State> &state,bool verify);
 
 	virtual ~MASHDecompressor();
 
@@ -17,12 +20,12 @@ public:
 	virtual void decompressImpl(Buffer &rawData,const Buffer &previousData,bool verify) override final;
 
 	static bool detectHeaderXPK(uint32_t hdr) noexcept;
-	static std::unique_ptr<XPKDecompressor> create(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::unique_ptr<XPKDecompressor::State> &state,bool verify);
+	static std::shared_ptr<XPKDecompressor> create(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::shared_ptr<XPKDecompressor::State> &state,bool verify);
 
 private:
 	const Buffer	&_packedData;
-
-	static XPKDecompressor::Registry<MASHDecompressor> _XPKregistration;
 };
 
+}
+
 #endif
