@@ -3,18 +3,23 @@
 #include <cstring>
 
 #include "NONEDecompressor.hpp"
+#include "common/Common.hpp"
+
+
+namespace ancient::internal
+{
 
 bool NONEDecompressor::detectHeaderXPK(uint32_t hdr) noexcept
 {
 	return hdr==FourCC("NONE");
 }
 
-std::unique_ptr<XPKDecompressor> NONEDecompressor::create(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::unique_ptr<XPKDecompressor::State> &state,bool verify)
+std::shared_ptr<XPKDecompressor> NONEDecompressor::create(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::shared_ptr<XPKDecompressor::State> &state,bool verify)
 {
-	return std::make_unique<NONEDecompressor>(hdr,recursionLevel,packedData,state,verify);
+	return std::make_shared<NONEDecompressor>(hdr,recursionLevel,packedData,state,verify);
 }
 
-NONEDecompressor::NONEDecompressor(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::unique_ptr<XPKDecompressor::State> &state,bool verify) :
+NONEDecompressor::NONEDecompressor(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::shared_ptr<XPKDecompressor::State> &state,bool verify) :
 	XPKDecompressor(recursionLevel),
 	_packedData(packedData)
 {
@@ -39,4 +44,4 @@ void NONEDecompressor::decompressImpl(Buffer &rawData,const Buffer &previousData
 	std::memcpy(rawData.data(),_packedData.data(),_packedData.size());
 }
 
-XPKDecompressor::Registry<NONEDecompressor> NONEDecompressor::_XPKregistration;
+}
