@@ -8,6 +8,9 @@
 
 #include "common/Buffer.hpp"
 
+namespace ancient::internal
+{
+
 class ForwardOutputStream
 {
 public:
@@ -53,4 +56,6 @@ private:
 	size_t		_endOffset;
 };
 
+}
+
 #endif
