@@ -5,10 +5,13 @@
 
 #include "XPKDecompressor.hpp"
 
+namespace ancient::internal
+{
+
 class SQSHDecompressor : public XPKDecompressor
 {
 public:
-	SQSHDecompressor(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::unique_ptr<XPKDecompressor::State> &state,bool verify);
+	SQSHDecompressor(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::shared_ptr<XPKDecompressor::State> &state,bool verify);
 
 	virtual ~SQSHDecompressor();
 
@@ -17,14 +20,14 @@ public:
 	virtual void decompressImpl(Buffer &rawData,const Buffer &previousData,bool verify) override final;
 
 	static bool detectHeaderXPK(uint32_t hdr) noexcept;
-	static std::unique_ptr<XPKDecompressor> create(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::unique_ptr<XPKDecompressor::State> &state,bool verify);
+	static std::shared_ptr<XPKDecompressor> create(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::shared_ptr<XPKDecompressor::State> &state,bool verify);
 
 private:
 	const Buffer	&_packedData;
 
 	uint32_t	_rawSize=0;
-
-	static XPKDecompressor::Registry<SQSHDecompressor> _XPKregistration;
 };
 
+}
+
 #endif
