@@ -6,6 +6,11 @@
 #include "OutputStream.hpp"
 #include "DLTADecode.hpp"
 #include "common/MemoryBuffer.hpp"
+#include "common/Common.hpp"
+
+
+namespace ancient::internal
+{
 
 SXSCDecompressor::SXSCReader::SXSCReader(ForwardInputStream &stream) :
 	_reader(stream)
@@ -29,12 +34,12 @@ bool SXSCDecompressor::detectHeaderXPK(uint32_t hdr) noexcept
 	return hdr==FourCC("SASC")||hdr==FourCC("SHSC");
 }
 
-std::unique_ptr<XPKDecompressor> SXSCDecompressor::create(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::unique_ptr<XPKDecompressor::State> &state,bool verify)
+std::shared_ptr<XPKDecompressor> SXSCDecompressor::create(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::shared_ptr<XPKDecompressor::State> &state,bool verify)
 {
-	return std::make_unique<SXSCDecompressor>(hdr,recursionLevel,packedData,state,verify);
+	return std::make_shared<SXSCDecompressor>(hdr,recursionLevel,packedData,state,verify);
 }
 
-SXSCDecompressor::SXSCDecompressor(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::unique_ptr<XPKDecompressor::State> &state,bool verify) :
+SXSCDecompressor::SXSCDecompressor(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::shared_ptr<XPKDecompressor::State> &state,bool verify) :
 	XPKDecompressor(recursionLevel),
 	_packedData(packedData),
 	_isHSC(hdr==FourCC("SHSC"))
@@ -192,10 +197,10 @@ void SXSCDecompressor::decompressASC(Buffer &rawData,ForwardInputStream &inputSt
 		if (bit)
 		{
 			// literal
-			outputStream.writeByte(twoStepArithDecoder(litInitial,litDynamic,litThreshold,1000,1,8));
+			outputStream.writeByte(uint8_t(twoStepArithDecoder(litInitial,litDynamic,litThreshold,1000,1,8)));
 		} else {
 			// copy
-			while (outputStream.getOffset()>size_t(1<<distanceIndex) && distanceIndex<15)
+			while (outputStream.getOffset()>(1ULL<<distanceIndex) && distanceIndex<15U)
 				updateTable(distanceCodes,6000,++distanceIndex,24);
 			uint16_t distanceValue=arithDecoder.decode(tableSize(distanceCodes));
 			uint16_t distanceBits=decodeSymbol(distanceCodes,distanceValue);
@@ -205,7 +210,7 @@ void SXSCDecompressor::decompressASC(Buffer &rawData,ForwardInputStream &inputSt
 			if (distanceBits>=2)
 			{
 				uint16_t minRange=1<<(distanceBits-1);
-				uint16_t range=distanceIndex==distanceBits?std::min(outputStream.getOffset(),size_t(31200U))-minRange:minRange;
+				uint16_t range=distanceIndex==distanceBits?static_cast<uint16_t>(std::min(outputStream.getOffset(),size_t(31200U)))-minRange:minRange;
 				distance=arithDecoder.decode(range);
 				arithDecoder.scale(distance,distance+1,range);
 				distance+=minRange;
@@ -642,7 +647,7 @@ void SXSCDecompressor::decompressHSC(Buffer &rawData,ForwardInputStream &inputSt
 				auto &frequencyFI=frequencies[freqIndex];
 				frequencyFI.frequency=1U;
 				frequencyFI.next=0xffffU;
-				frequencyFI.character=ch;
+				frequencyFI.character=uint8_t(ch);
 				model.escapeFrequency++;
 				model.characterCount++;
 			} else if (++frequencies[freqIndex].frequency==3) {
@@ -726,7 +731,7 @@ void SXSCDecompressor::decompressHSC(Buffer &rawData,ForwardInputStream &inputSt
 			}
 			frequency.next=0xffffU;
 			frequency.frequency=1;
-			frequency.character=ch;
+			frequency.character=uint8_t(ch);
 			model.escapeFrequency=1;
 			model.frequencyTotal=1;
 			model.contextLength=maxLength;
@@ -738,12 +743,12 @@ void SXSCDecompressor::decompressHSC(Buffer &rawData,ForwardInputStream &inputSt
 			hashes[hashValue].data=le;
 		}
 
-		outputStream.writeByte(ch);
+		outputStream.writeByte(uint8_t(ch));
 		for (uint16_t i=3;i!=0;i--)
 		{
 			currentContext[i]=currentContext[i-1];
 		}
-		currentContext[0]=ch;
+		currentContext[0]=uint8_t(ch);
 	}
 	if (!outputStream.eof()) throw Decompressor::DecompressionError();
 }
@@ -821,4 +826,4 @@ void SXSCDecompressor::decompressImpl(Buffer &rawData,const Buffer &previousData
 	}
 }
 
-XPKDecompressor::Registry<SXSCDecompressor> SXSCDecompressor::_XPKregistration;
+}
