@@ -5,6 +5,9 @@
 
 #include "Decompressor.hpp"
 
+namespace ancient::internal
+{
+
 class StoneCrackerDecompressor : public Decompressor
 {
 public:
@@ -21,7 +24,7 @@ public:
 
 	static bool detectHeader(uint32_t hdr) noexcept;
 
-	static std::unique_ptr<Decompressor> create(const Buffer &packedData,bool exactSizeKnown,bool verify);
+	static std::shared_ptr<Decompressor> create(const Buffer &packedData,bool exactSizeKnown,bool verify);
 
 private:
 	static bool detectHeaderAndGeneration(uint32_t hdr,uint32_t &generation) noexcept;
@@ -42,8 +45,8 @@ private:
 	uint8_t		_rle[3];
 	uint32_t	_generation;
 	uint32_t	_dataOffset;
-
-	static Decompressor::Registry<StoneCrackerDecompressor> _registration;
 };
 
+}
+
 #endif
