@@ -8,6 +8,9 @@
 
 #include <exception>
 
+namespace ancient::internal
+{
+
 class Buffer
 {
 protected:
@@ -16,22 +19,23 @@ protected:
 public:
 	class Error : public std::exception
 	{
-		// nothing needed
+	public:
+		Error() noexcept;
+		virtual ~Error();
 	};
 
 	class OutOfBoundsError : public Error
 	{
-		// nothing needed
+	public:
+		OutOfBoundsError() noexcept;
+		virtual ~OutOfBoundsError();
 	};
 
 	class InvalidOperationError : public Error
 	{
-		// nothing needed
-	};
-
-	class OutOfMemoryError : public Error
-	{
-		// nothing needed
+	public:
+		InvalidOperationError() noexcept;
+		virtual ~InvalidOperationError();
 	};
 
 	Buffer(const Buffer&)=delete;
@@ -71,4 +75,6 @@ public:
 	uint8_t read8(size_t offset) const;
 };
 
+}
+
 #endif
