@@ -8,6 +8,9 @@
 
 #include "Buffer.hpp"
 
+namespace ancient::internal
+{
+
 template<size_t N>
 class StaticBuffer : public Buffer
 {
@@ -64,4 +67,6 @@ private:
 	size_t		_length;
 };
 
+}
+
 #endif
